@@ -51,15 +51,8 @@
 /* How long one has to press a checklist item before editing starts */
 #define CHECKLIST_LONGPRESS_EDIT_DELAY 1000
 
-#define NEW_SEL_LOGIC
-#define EXPANDING_ROWS
-
-
-#ifndef EXPANDING_ROWS
-	#error EXPANDING_ROWS is needed for NEW_SEL_LOGIC
-#endif
-
 #define _(String) gettext(String)
+#define N_(a, b, c) ngettext(a, b, c)
 
 #define USE_TEMP_TABLES
 
@@ -177,7 +170,6 @@ struct _MainView
 		GtkWidget *tools_pagestyle;
 		GtkWidget *tools_shape;
 		GtkWidget *tools_font;
-		GtkWidget *tools_wordwrap;
 		GtkWidget *tools_color;
 		GtkWidget *tools_pressure;
 		
@@ -218,6 +210,8 @@ struct _MainView
 		GtkToolItem *shape_tb;
 		GtkWidget *shapemenuitems[4];
 
+                GtkToolItem* sharing_tb;
+
 		GtkToolItem* fullscreen_tb;
 
 		/*
@@ -257,8 +251,17 @@ struct _MainView
                 GtkWidget* menu_button_delete;
                 GtkWidget* menu_button_export;
                 GtkWidget* menu_button_clear;
+
+                /* Sketch-specific */
                 GtkWidget* menu_button_square;
                 GtkWidget* menu_button_filled;
+
+                /* Rich text-specific */
+                GtkWidget* menu_button_wordwrap;
+
+                /* Checklist-specific */
+                GtkWidget* menu_button_remove_checked;
+
                 /* End AppMenu stuff */
 
                 gboolean can_show_node_view;
@@ -267,16 +270,23 @@ struct _MainView
 
 		guint busyrefcount;
 
+                /* The previous keyval in the node view window */
+                guint node_view_prev_keyval;
+                /* If TRUE, node_view_prev_keyval will be reset */
+                gboolean node_view_prev_keyval_reset;
+
+                /* Same as above, but for the main view */
+                guint main_view_prev_keyval;
+                gboolean main_view_prev_keyval_reset;
+
 		gboolean file_edited;				/* for node operations and notification of new stuff in tmptable */
 		gchar *file_name;
 		gboolean loading;
 
 		sqlite3 *db;
 
-#ifdef NEW_SEL_LOGIC
 		nodeData *cansel_node;
 		guint32 cansel_time;
-#endif
 
 		gboolean newnodedialog_createchild;
 	};
